@@ -81,7 +81,19 @@ class AlitaClient:
     def mcp_tool_call(self, params: dict[str, Any]):
         if user_id := self._get_real_user_id():
             url = f"{self.mcp_tools_call}/{user_id}"
-            data = requests.post(url, headers=self.headers, json=params, verify=False).json()
+
+            if 'args' in params.get('params', {}).get('arguments', {}):
+                args_obj = params['params']['arguments']['args']
+                if hasattr(args_obj, "__dict__"):
+                    params['params']['arguments'] = vars(args_obj)
+                else:
+                    params['params']['arguments'] = args_obj
+
+            response = requests.post(url, headers=self.headers, json=params, verify=False)
+            try:
+                data = response.json()
+            except (ValueError, TypeError):
+                data = response.text
             return data
         else:
             return f"Error: Could not determine user ID for MCP tool call"
@@ -900,24 +912,3 @@ class AlitaClient:
                 "events_dispatched": [],
                 "execution_time_seconds": 0.0
             }
-
-    def _get_real_user_id(self) -> str:
-        """Extract the real user ID from the auth token for MCP tool calls."""
-        try:
-            import base64
-            import json
-            # Assuming JWT token, extract user ID from payload
-            # This is a basic implementation - adjust based on your token format
-            token_parts = self.auth_token.split('.')
-            if len(token_parts) >= 2:
-                payload_part = token_parts[1]
-                # Add padding if needed
-                padding = len(payload_part) % 4
-                if padding:
-                    payload_part += '=' * (4 - padding)
-                payload = json.loads(base64.b64decode(payload_part))
-                return payload.get('user_id') or payload.get('sub') or payload.get('uid')
-        except Exception as e:
-            logger.error(f"Error extracting user ID from token: {e}")
-        return None
-
