@@ -73,6 +73,10 @@ class StepBackSearchDocumentsModel(BaseModel):
         }""",
         default=None
     )
+    extended_search: Optional[List[str]] = Field(
+        description="List of chunk types to search for (title, summary, propositions, keywords, documents)",
+        default=None
+    )
     reranking_config: Optional[Dict[str, Dict[str, Any]]] = Field(
         description="""Reranking configuration. Example:
         {
@@ -87,10 +91,6 @@ class StepBackSearchDocumentsModel(BaseModel):
         }""",
         default=None
     )
-    extended_search: Optional[List[str]] = Field(
-        description="List of chunk types to search for (title, summary, propositions, keywords, documents)",
-        default=None
-    )
 
 STEPBACK_PROMPT = """Your task is to convert provided question into a more generic question that will be used for similarity search.
 Remove all not important words, question words, but save all names, dates and acronym as in original question.
@@ -212,10 +212,27 @@ class VectorStoreWrapper(BaseToolApiWrapper):
         """Get all indexed document IDs from vectorstore"""
         return self.vector_adapter.get_indexed_ids(self, collection_suffix)
 
-    def list_collections(self) -> List[str]:
-        """List all collections in the vectorstore."""
-
-        return self.vector_adapter.list_collections(self)
+    def list_collections(self) -> Any:
+        """List all collections in the vectorstore.
+        Returns a list of collection names, or if no collections exist,
+        returns a dict with an empty list and a message."""
+        raw = self.vector_adapter.list_collections(self)
+        # Normalize raw result to a list of names
+        if not raw:
+            # No collections found
+            return {"collections": [], "message": "No indexed collections"}
+        if isinstance(raw, str):
+            # e.g., Chroma adapter returns comma-separated string
+            cols = [c for c in raw.split(',') if c]
+        else:
+            try:
+                cols = list(raw)
+            except Exception:
+                # Unexpected type, return raw directly
+                return raw
+        if not cols:
+            return {"collections": [], "message": "No indexed collections"}
+        return cols
 
     def _clean_collection(self, collection_suffix: str = ''):
         """
@@ -266,6 +283,7 @@ class VectorStoreWrapper(BaseToolApiWrapper):
 
         for document in documents:
             key = key_fn(document)
+            key = key if isinstance(key, str) else str(key)
             if key in indexed_keys and collection_suffix == indexed_data[key]['metadata'].get('collection'):
                 if compare_fn(document, indexed_data[key]):
                     # Disabled addition of new collection to already indexed documents
@@ -728,7 +746,7 @@ class VectorStoreWrapper(BaseToolApiWrapper):
 
         try:
             dispatch_custom_event(
-                name="thinking_step",
+                name="thinking_step_update",
                 data={
                     "message": message,
                     "tool_name": tool_name,
@@ -765,4 +783,3 @@ class VectorStoreWrapper(BaseToolApiWrapper):
                 "args_schema": StepBackSearchDocumentsModel
             }
         ]
-
