@@ -66,22 +66,22 @@ BaseStepbackSearchParams = create_model(
     )),
     cut_off=(Optional[float], Field(description="Cut-off score for search results", default=0.5, ge=0, le=1)),
     search_top=(Optional[int], Field(description="Number of top results to return", default=10)),
-    reranker=(Optional[dict], Field(
-        description="Reranker configuration. Can be a dictionary with reranking parameters.",
-        default={}
-    )),
     full_text_search=(Optional[Dict[str, Any]], Field(
         description="Full text search parameters. Can be a dictionary with search options.",
         default=None
     )),
-    reranking_config=(Optional[Dict[str, Dict[str, Any]]], Field(
-        description="Reranking configuration. Can be a dictionary with reranking settings.",
-        default=None
-    )),
     extended_search=(Optional[List[str]], Field(
         description="List of additional fields to include in the search results.",
         default=None
     )),
+    reranker=(Optional[dict], Field(
+            description="Reranker configuration. Can be a dictionary with reranking parameters.",
+            default={}
+        )),
+    reranking_config=(Optional[Dict[str, Dict[str, Any]]], Field(
+            description="Reranking configuration. Can be a dictionary with reranking settings.",
+            default=None
+        )),
 )
 
 BaseIndexDataParams = create_model(
@@ -126,6 +126,11 @@ class BaseIndexerToolkit(VectorStoreWrapperBase):
         """
         return {}
 
+    def _remove_metadata_keys(self) -> List[str]:
+        """ Returns a list of metadata keys to be removed from documents before indexing.
+        Override this method in subclasses to provide specific keys to remove."""
+        return [IndexerKeywords.CONTENT_IN_BYTES.value, IndexerKeywords.CONTENT_FILE_NAME.value]
+
     def _base_loader(self, **kwargs) -> Generator[Document, None, None]:
         """ Loads documents from a source, processes them,
         and returns a list of Document objects with base metadata: id and created_on."""
@@ -153,16 +158,26 @@ class BaseIndexerToolkit(VectorStoreWrapperBase):
         if clean_index:
             self._clean_index(collection_suffix)
         #
+        self._log_tool_event(f"Indexing data into collection with suffix '{collection_suffix}'. It can take some time...")
+        self._log_tool_event(f"Loading the documents to index...{kwargs}")
         documents = self._base_loader(**kwargs)
+        self._log_tool_event(f"Base documents were loaded. "
+                             f"Search for possible document duplicates and remove them from the indexing list...")
         documents = self._reduce_duplicates(documents, collection_suffix)
+        self._log_tool_event(f"Duplicates were removed. "
+                             f"Processing documents to collect dependencies and prepare them for indexing...")
         documents = self._extend_data(documents) # update content of not-reduced base document if needed (for sharepoint and similar)
         documents = self._collect_dependencies(documents) # collect dependencies for base documents
+        self._log_tool_event(f"Documents were processed. "
+                             f"Applying chunking tool '{chunking_tool}' if specified and preparing documents for indexing...")
         documents = self._apply_loaders_chunkers(documents, chunking_tool, chunking_config)
-        #
-        return self._save_index(list(documents), collection_suffix=collection_suffix, progress_step=progress_step)
+        list_documents = list(documents)
+        self._clean_metadata(list_documents)
+        self._log_tool_event(f"Documents are ready for indexing. Total documents to index: {len(list_documents)}")
+        return self._save_index(list_documents, collection_suffix=collection_suffix, progress_step=progress_step)
     
     def _apply_loaders_chunkers(self, documents: Generator[Document, None, None], chunking_tool: str=None, chunking_config=None) -> Generator[Document, None, None]:
-        from alita_sdk.tools.chunkers import __all__ as chunkers
+        from ..tools.chunkers import __all__ as chunkers
 
         if chunking_config is None:
             chunking_config = {}
@@ -177,7 +192,11 @@ class BaseIndexerToolkit(VectorStoreWrapperBase):
                     document=document,
                     content=content,
                     extension_source=content_type, llm=self.llm, chunking_config=chunking_config)
-            elif chunking_tool and (content_in_bytes := document.metadata.pop(IndexerKeywords.CONTENT_IN_BYTES.value, None)):
+            elif chunking_tool and (content_in_bytes := document.metadata.pop(IndexerKeywords.CONTENT_IN_BYTES.value, None)) is not None:
+                if not content_in_bytes:
+                    # content is empty, yield as is
+                    yield document
+                    continue
                 # apply parsing based on content type resolved from chunking_tool
                 content_type = file_extension_by_chunker(chunking_tool)
                 yield from process_content_by_type(
@@ -203,6 +222,12 @@ class BaseIndexerToolkit(VectorStoreWrapperBase):
                 dep.metadata[IndexerKeywords.PARENT.value] = document.metadata.get('id', None)
                 yield dep
 
+    def _clean_metadata(self, documents: list[Document]):
+        for document in documents:
+            remove_keys = self._remove_metadata_keys()
+            for key in remove_keys:
+                document.metadata.pop(key, None)
+
     def _reduce_duplicates(
             self,
             documents: Generator[Any, None, None],
@@ -222,6 +247,7 @@ class BaseIndexerToolkit(VectorStoreWrapperBase):
 
         for document in documents:
             key = self.key_fn(document)
+            key = key if isinstance(key, str) else str(key)
             if key in indexed_keys and collection_suffix == indexed_data[key]['metadata'].get('collection'):
                 if self.compare_fn(document, indexed_data[key]):
                     continue
