@@ -90,22 +90,23 @@ BaseStepbackSearchParams = create_model(
     )),
     cut_off=(Optional[float], Field(description="Cut-off score for search results", default=0.5, ge=0, le=1)),
     search_top=(Optional[int], Field(description="Number of top results to return", default=10, ge=0)),
-    reranker=(Optional[dict], Field(
-        description="Reranker configuration. Can be a dictionary with reranking parameters.",
-        default={}
-    )),
     full_text_search=(Optional[Dict[str, Any]], Field(
         description="Full text search parameters. Can be a dictionary with search options.",
         default=None
     )),
-    reranking_config=(Optional[Dict[str, Dict[str, Any]]], Field(
-        description="Reranking configuration. Can be a dictionary with reranking settings.",
-        default=None
-    )),
     extended_search=(Optional[List[str]], Field(
         description="List of additional fields to include in the search results.",
         default=None
     )),
+    reranker=(Optional[dict], Field(
+        description="Reranker configuration. Can be a dictionary with reranking parameters.",
+        default={}
+    )),
+    reranking_config=(Optional[Dict[str, Dict[str, Any]]], Field(
+        description="Reranking configuration. Can be a dictionary with reranking settings.",
+        default=None
+    )),
+
 )
 
 BaseIndexDataParams = create_model(
@@ -136,7 +137,7 @@ class BaseToolApiWrapper(BaseModel):
 
             logger.info(message)
             dispatch_custom_event(
-                name="thinking_step",
+                name="thinking_step_update",
                 data={
                     "message": message,
                     "tool_name": tool_name,
@@ -575,6 +576,10 @@ class BaseCodeToolApiWrapper(BaseVectorStoreToolApiWrapper):
             raise ValueError("Expected a list of strings")
         return _files
 
+    def __get_branch(self, branch):
+       return (branch or getattr(self, 'active_branch', None)
+               or getattr(self, '_active_branch', None) or getattr(self, 'branch', None))
+
     def loader(self,
                branch: Optional[str] = None,
                whitelist: Optional[List[str]] = None,
@@ -600,7 +605,7 @@ class BaseCodeToolApiWrapper(BaseVectorStoreToolApiWrapper):
         """
         from .chunkers.code.codeparser import parse_code_files_for_db
 
-        _files = self.__handle_get_files("", branch or self.active_branch or self._active_branch)
+        _files = self.__handle_get_files("", self.__get_branch(branch))
         self._log_tool_event(message="Listing files in branch", tool_name="loader")
         logger.info(f"Files in branch: {_files}")
 
@@ -623,7 +628,14 @@ class BaseCodeToolApiWrapper(BaseVectorStoreToolApiWrapper):
             for idx, file in enumerate(_files, 1):
                 if is_whitelisted(file) and not is_blacklisted(file):
                     # read file ONLY if it matches whitelist and does not match blacklist
-                    file_content = self._read_file(file, branch=branch or self.active_branch or self._active_branch)
+                    try:
+                        file_content = self._read_file(file, self.__get_branch(branch))
+                    except Exception as e:
+                        logger.error(f"Failed to read file {file}: {e}")
+                        file_content = ""
+                    if not file_content:
+                        # empty file, skip
+                        continue
                     # hash the file content to ensure uniqueness
                     import hashlib
                     file_hash = hashlib.sha256(file_content.encode("utf-8")).hexdigest()
@@ -652,7 +664,8 @@ class BaseCodeToolApiWrapper(BaseVectorStoreToolApiWrapper):
         vectorstore = self._init_vector_store()
         clean_index = kwargs.get('clean_index', False)
         return vectorstore.index_documents(documents, collection_suffix=collection_suffix,
-                                           clean_index=clean_index, is_code=True)
+                                           clean_index=clean_index, is_code=True,
+                                           progress_step=kwargs.get('progress_step', 5))
 
     def _get_vector_search_tools(self):
         """
