@@ -9,6 +9,8 @@ from langchain_core.tools import ToolException
 
 from ..non_code_indexer_toolkit import NonCodeIndexerToolkit
 from ..utils.available_tools_decorator import extend_with_parent_available_tools
+from ..utils.content_parser import file_extension_by_chunker
+from ...runtime.utils.utils import IndexerKeywords
 
 
 class ZephyrEssentialApiWrapper(NonCodeIndexerToolkit):
@@ -179,12 +181,43 @@ class ZephyrEssentialApiWrapper(NonCodeIndexerToolkit):
     def create_folder(self, json: str):
         """Create a new folder."""
         folder_data = self._parse_json(json)
+        if 'parentId' not in folder_data:
+            if 'parentName' in folder_data:
+                parent_folder_name = folder_data['parentName']
+
+                parent_folder = self.find_folder_by_name(parent_folder_name)
+
+                if isinstance(parent_folder, ToolException):
+                    return ToolException(f"Folder with name '{parent_folder_name}' not found.")
+                else:
+                    folder_data['parentId'] = parent_folder['id']
+
         return self._client.create_folder(folder_data)
 
     def get_folder(self, folder_id: str):
         """Retrieve details of a specific folder."""
         return self._client.get_folder(folder_id)
 
+    def find_folder_by_name(self, name: str, project_key: Optional[str] = None, folder_type: Optional[str] = None):
+        """
+        Find a folder by its name, ignoring case.
+
+        :param name: The name of the folder to search for.
+        :param project_key: Optional filter by project key.
+        :param folder_type: Optional filter by folder type.
+        :return: The folder details if found, otherwise None.
+        """
+        # Fetch all folders with optional filters
+        folders = self.list_folders(project_key=project_key, folder_type=folder_type)
+
+        # Iterate through the folders and search for the matching name
+        for folder in folders['values']:
+            if folder.get('name', '').lower() == name.lower():
+                return folder
+
+        # Return None if no folder is found
+        return ToolException(f"Folder with name {name} was not found")
+
     def delete_link(self, link_id: str):
         """Delete a specific link."""
         return self._client.delete_link(link_id)
@@ -239,6 +272,7 @@ class ZephyrEssentialApiWrapper(NonCodeIndexerToolkit):
         }
 
     def _base_loader(self, **kwargs) -> Generator[Document, None, None]:
+        self._chunking_tool = kwargs.get('chunking_tool', None)
         try:
             test_cases = self.list_test_cases()
         except Exception as e:
@@ -260,7 +294,10 @@ class ZephyrEssentialApiWrapper(NonCodeIndexerToolkit):
                     additional_content = self._process_test_case(document.metadata['key'])
                     for steps_type, content in additional_content.items():
                         if content:
-                            document.page_content = json.dumps(content)
+                            page_content = json.dumps(content)
+                            document.metadata[IndexerKeywords.CONTENT_IN_BYTES.value] = page_content.encode('utf-8')
+                            document.metadata[
+                                IndexerKeywords.CONTENT_FILE_NAME.value] = f"base_doc{file_extension_by_chunker(self._chunking_tool)}"
                             document.metadata["steps_type"] = steps_type
             except Exception as e:
                 logging.error(f"Failed to process document: {e}")
@@ -482,6 +519,12 @@ class ZephyrEssentialApiWrapper(NonCodeIndexerToolkit):
                 "args_schema": GetFolder,
                 "ref": self.get_folder,
             },
+            {
+                "name": "find_folder_by_name",
+                "description": self.find_folder_by_name.__doc__,
+                "args_schema": FindFolderByName,
+                "ref": self.find_folder_by_name,
+            },
             {
                 "name": "delete_link",
                 "description": self.delete_link.__doc__,
@@ -577,8 +620,74 @@ UpdateTestCase = create_model(
     json=(str, Field(description=("""
         JSON body to update a test case. Example:
         {
-          "name": "Updated Test Case Name",
-          "description": "Updated Test Case Description"
+          "id": 1,
+          "key": "SA-T10",
+          "name": "Check axial pump",
+          "project": {
+            "id": 10005,
+            "self": "https://<api-base-url>/projects/10005"
+          },
+          "createdOn": "2018-05-15T13:15:13Z",
+          "objective": "To ensure the axial pump can be enabled",
+          "precondition": "Latest version of the axial pump available",
+          "estimatedTime": 138000,
+          "labels": [
+            "Regression",
+            "Performance",
+            "Automated"
+          ],
+          "component": {
+            "id": 10001,
+            "self": "https://<jira-instance>.atlassian.net/rest/api/2/component/10001"
+          },
+          "priority": {
+            "id": 10002,
+            "self": "https://<api-base-url>/priorities/10002"
+          },
+          "status": {
+            "id": 10000,
+            "self": "https://<api-base-url>/statuses/10000"
+          },
+          "folder": {
+            "id": 100006,
+            "self": "https://<api-base-url>/folders/10006"
+          },
+          "owner": {
+            "self": "https://<jira-instance>.atlassian.net/rest/api/2/user?accountId=5b10a2844c20165700ede21g",
+            "accountId": "5b10a2844c20165700ede21g"
+          },
+          "testScript": {
+            "self": "https://<api-base-url>/testCases/PROJ-T1/testscript"
+          },
+          "customFields": {
+            "Build Number": 20,
+            "Release Date": "2020-01-01",
+            "Pre-Condition(s)": "User should have logged in. <br> User should have navigated to the administration panel.",
+            "Implemented": false,
+            "Category": [
+              "Performance",
+              "Regression"
+            ],
+            "Tester": "fa2e582e-5e15-521e-92e3-47e6ca2e7256"
+          },
+          "links": {
+            "self": "string",
+            "issues": [
+              {
+                "self": "string",
+                "issueId": 10100,
+                "id": 1,
+                "target": "https://<jira-instance>.atlassian.net/rest/api/2/issue/10000",
+                "type": "COVERAGE"
+              }
+            ],
+            "webLinks": [
+              {
+                "self": "string",
+                "description": "A link to atlassian.com",
+                "url": "https://atlassian.com",
+                "id": 1,
+                "type": "COVERAGE"
         }
         """
     )))
@@ -595,9 +704,9 @@ CreateTestCaseIssueLink = create_model(
     json=(str, Field(description=("""
         JSON body to create an issue link. Example:
         {
-          "issueKey": "ISSUE_KEY",
-          "description": "Link Description"
+          "issueId": 10100
         }
+        where issueId - Jira issue id
         """
     )))
 )
@@ -639,8 +748,10 @@ CreateTestCaseTestScript = create_model(
     json=(str, Field(description=("""
         JSON body to create a test script. Example:
         {
-          "script": "Test Script Content"
+          "type": "bdd",
+          "text": "Attempt to login to the application"
         }
+        Where type - Test script type. Allowed: plain, bdd
         """
     )))
 )
@@ -657,13 +768,43 @@ CreateTestCaseTestSteps = create_model(
     test_case_key=(str, Field(description="Key of the test case to create test steps for.")),
     json=(str, Field(description=("""
         JSON body to create test steps. Example:
-        [
-          {
-            "step": "Step 1",
-            "data": "Test Data",
-            "result": "Expected Result"
-          }
-        ]
+        {
+          "mode": "APPEND",
+          "items": [
+            {
+              "inline": {
+                "description": "Attempt to login to the application",
+                "testData": "Username = SmartBear Password = weLoveAtlassian",
+                "expectedResult": "Login succeeds, web-app redirects to the dashboard view",
+                "customFields": {
+                  "Build Number": 20,
+                  "Release Date": "2020-01-01",
+                  "Pre-Condition(s)": "User should have logged in. <br> User should have navigated to the administration panel.",
+                  "Implemented": false,
+                  "Category": [
+                    "Performance",
+                    "Regression"
+                  ],
+                  "Tester": "fa2e582e-5e15-521e-92e3-47e6ca2e7256"
+                }
+              },
+              "testCase": {
+                "self": "string",
+                "testCaseKey": "PROJ-T123",
+                "parameters": [
+                  {
+                    "name": "username",
+                    "type": "DEFAULT_VALUE",
+                    "value": "admin"
+                  }
+                ]
+              }
+            }
+          ]
+        }
+        Where:
+        mode: str - required - Valid values: "APPEND", "OVERWRITE",
+        items - The list of test steps. Each step should be an object containing inline or testCase. They should only include one of these fields at a time.
         """
     )))
 )
@@ -701,9 +842,71 @@ UpdateTestCycle = create_model(
     json=(str, Field(description=("""
         JSON body to update a test cycle. Example:
         {
-          "name": "Updated Test Cycle Name",
-          "description": "Updated Test Cycle Description"
-        }
+          "id": 1,
+          "key": "SA-R40",
+          "name": "Sprint 1 Regression Test Cycle",
+          "project": {
+            "id": 10005,
+            "self": "https://<api-base-url>/projects/10005"
+          },
+          "jiraProjectVersion": {
+            "id": 10000,
+            "self": "https://<jira-instance>.atlassian.net/rest/api/2/version/10000"
+          },
+          "status": {
+            "id": 10000,
+            "self": "https://<api-base-url>/statuses/10000"
+          },
+          "folder": {
+            "id": 100006,
+            "self": "https://<api-base-url>/folders/10006"
+          },
+          "description": "Regression test cycle 1 to ensure no breaking changes",
+          "plannedStartDate": "2018-05-19T13:15:13Z",
+          "plannedEndDate": "2018-05-20T13:15:13Z",
+          "owner": {
+            "self": "https://<jira-instance>.atlassian.net/rest/api/2/user?accountId=5b10a2844c20165700ede21g",
+            "accountId": "5b10a2844c20165700ede21g"
+          },
+          "customFields": {
+            "Build Number": 20,
+            "Release Date": "2020-01-01",
+            "Pre-Condition(s)": "User should have logged in. <br> User should have navigated to the administration panel.",
+            "Implemented": false,
+            "Category": [
+              "Performance",
+              "Regression"
+            ],
+            "Tester": "fa2e582e-5e15-521e-92e3-47e6ca2e7256"
+          },
+          "links": {
+            "self": "string",
+            "issues": [
+              {
+                "self": "string",
+                "issueId": 10100,
+                "id": 1,
+                "target": "https://<jira-instance>.atlassian.net/rest/api/2/issue/10000",
+                "type": "COVERAGE"
+              }
+            ],
+            "webLinks": [
+              {
+                "self": "string",
+                "description": "A link to atlassian.com",
+                "url": "https://atlassian.com",
+                "id": 1,
+                "type": "COVERAGE"
+              }
+            ],
+            "testPlans": [
+              {
+                "id": 1,
+                "self": "https://<api-base-url>/links/1",
+                "type": "RELATED",
+                "testPlanId": 2,
+                "target": "https://<jira-instance>.atlassian.net/rest/api/2/testplan/123"
+              }
         """
     )))
 )
@@ -719,9 +922,9 @@ CreateTestCycleIssueLink = create_model(
     json=(str, Field(description=("""
         JSON body to create an issue link. Example:
         {
-          "issueKey": "ISSUE_KEY",
-          "description": "Link Description"
+          "issueId": 10100
         }
+        where issueId - Jira issue id
         """
     )))
 )
@@ -753,10 +956,34 @@ CreateTestExecution = create_model(
     json=(str, Field(description=("""
         JSON body to create a test execution. Example:
         {
-          "testCaseKey": "TEST_CASE_KEY",
-          "testCycleKey": "TEST_CYCLE_KEY",
-          "status": "PASS"
-        }
+          "projectKey": "TIS",
+          "testCaseKey": "SA-T10",
+          "testCycleKey": "SA-R10",
+          "statusName": "In Progress",
+          "testScriptResults": [
+            {
+              "statusName": "In Progress",
+              "actualEndDate": "2018-05-20T13:15:13Z",
+              "actualResult": "User logged in successfully"
+            }
+          ],
+          "environmentName": "Chrome Latest Version",
+          "actualEndDate": "2018-05-20T13:15:13Z",
+          "executionTime": 120000,
+          "executedById": "5b10a2844c20165700ede21g",
+          "assignedToId": "5b10a2844c20165700ede21g",
+          "comment": "Test failed user could not login",
+          "customFields": {
+            "Build Number": 20,
+            "Release Date": "2020-01-01",
+            "Pre-Condition(s)": "User should have logged in. <br> User should have navigated to the administration panel.",
+            "Implemented": false,
+            "Category": [
+              "Performance",
+              "Regression"
+            ],
+            "Tester": "fa2e582e-5e15-521e-92e3-47e6ca2e7256"
+          }
         """
     )))
 )
@@ -772,8 +999,13 @@ UpdateTestExecution = create_model(
     json=(str, Field(description=("""
         JSON body to update a test execution. Example:
         {
-          "status": "FAIL",
-          "comment": "Updated comment"
+          "statusName": "In Progress",
+          "environmentName": "Chrome Latest Version",
+          "actualEndDate": "2018-05-20T13:15:13Z",
+          "executionTime": 120000,
+          "executedById": "5b10a2844c20165700ede21g",
+          "assignedToId": "5b10a2844c20165700ede21g",
+          "comment": "Test failed user could not login"
         }
         """
     )))
@@ -791,12 +1023,14 @@ UpdateTestExecutionTestSteps = create_model(
     test_execution_id_or_key=(str, Field(description="ID or key of the test execution to update test steps for.")),
     json=(str, Field(description=("""
         "JSON body to update test steps. Example:
-        ["
-          {"
-            "step": "Step 1",
-            "status": "PASS"
-          }
-        ]
+        {
+          "steps": [
+            {
+              "actualResult": "User logged in successfully",
+              "statusName": "In Progress"
+            }
+          ]
+        }
         """
     )))
 )
@@ -817,9 +1051,9 @@ CreateTestExecutionIssueLink = create_model(
     json=(str, Field(description=("""
         JSON body to create an issue link. Example:
         {
-          "issueKey": "ISSUE_KEY",
-          "description": "Link Description"
+          "issueId": 10100
         }
+        where issueId - Jira issue id
         """
     )))
 )
@@ -848,10 +1082,13 @@ CreateFolder = create_model(
     json=(str, Field(description=("""
         JSON body to create a folder. Example:
         {
-          "name": "Folder Name",
-          "description": "Folder Description",
-          "projectKey": "PROJECT_KEY"
+            "parentId": 123456,
+            "parentName": "parentFolder",
+            "name": "ZephyrEssential_test",
+            "projectKey": "PRJ",
+            "folderType": "TEST_CASE"
         }
+        Possible folder types: "TEST_CASE", "TEST_PLAN", "TEST_CYCLE",
         """
     )))
 )
@@ -861,6 +1098,14 @@ GetFolder = create_model(
     folder_id=(str, Field(description="ID of the folder to retrieve."))
 )
 
+FindFolderByName = create_model(
+    "GetFolder",
+    name=(str, Field(description="Name of the folder to retrieve.")),
+    project_key=(Optional[str], Field(description="Project key", default=None)),
+    folder_type=(Optional[str], Field(description="""Folder type. Possible values: "TEST_CASE", "TEST_PLAN", "TEST_CYCLE" """,
+                                      default=None)),
+)
+
 DeleteLink = create_model(
     "DeleteLink",
     link_id=(str, Field(description="ID of the link to delete."))
