@@ -40,7 +40,7 @@ class ZephyrScaleToolkit(BaseToolkit):
         return create_model(
             name,
             max_results=(int, Field(default=100, description="Results count to show")),
-            zephyr_configuration=(Optional[ZephyrConfiguration], Field(description="Zephyr Configuration",
+            zephyr_configuration=(ZephyrConfiguration, Field(description="Zephyr Configuration",
                                                                        json_schema_extra={'configuration_types': ['zephyr']})),
             pgvector_configuration=(Optional[PgVectorConfiguration], Field(default=None, description="PgVector Configuration",
                                                                            json_schema_extra={
